@@ -1,7 +1,7 @@
-﻿/*
+/*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 1999-2017 Vaclav Slavik
+ *  Copyright (C) 1999-2018 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -89,8 +89,10 @@
 #ifdef __WXOSX__
 struct PoeditApp::NativeMacAppData
 {
-    NSMenu *menu = nullptr;
-    NSMenuItem *menuItem = nullptr;
+    NSMenu *recentMenu = nullptr;
+    NSMenuItem *recentMenuItem = nullptr;
+    NSMenu *windowMenu = nullptr;
+    NSMenuItem *windowMenuItem = nullptr;
     wxMenuBar *menuBar = nullptr;
 #ifdef USE_SPARKLE
     NSObject *sparkleDelegate = nullptr;
@@ -267,6 +269,7 @@ PoeditApp::PoeditApp()
 {
 #ifdef __WXOSX__
     m_nativeMacAppData.reset(new NativeMacAppData);
+    wxMenuBar::SetAutoWindowMenu(false);
 #endif
 }
 
@@ -833,7 +836,7 @@ BEGIN_EVENT_TABLE(PoeditApp, wxApp)
 #endif
 #ifdef __WXOSX__
    EVT_MENU           (wxID_CLOSE, PoeditApp::OnCloseWindowCommand)
-   EVT_IDLE           (PoeditApp::OnIdleInstallOpenRecentMenu)
+   EVT_IDLE           (PoeditApp::OnIdleFixupMenusForMac)
 #endif
 END_EVENT_TABLE()
 
@@ -931,7 +934,7 @@ void PoeditApp::OnAbout(wxCommandEvent&)
     about.SetVersion(wxGetApp().GetAppVersion());
     about.SetDescription(_("Poedit is an easy to use translations editor."));
 #endif
-    about.SetCopyright(L"Copyright \u00a9 1999-2017 Václav Slavík");
+    about.SetCopyright(L"Copyright \u00a9 1999-2018 Václav Slavík");
 #ifdef __WXGTK__ // other ports would show non-native about dlg
     about.SetWebSite("https://poedit.net");
 #endif
@@ -1032,7 +1035,7 @@ void PoeditApp::MacOpenFiles(const wxArrayString& names)
 }
 
 
-static NSMenuItem *AddNativeItem(NSMenu *menu, int pos, const wxString&text, SEL ac, NSString *key)
+static NSMenuItem *AddNativeItem(NSMenu *menu, int pos, const wxString& text, SEL ac, NSString *key)
 {
     NSString *str = str::to_NS(text);
     if (pos == -1)
@@ -1054,6 +1057,18 @@ void PoeditApp::TweakOSXMenuBar(wxMenuBar *bar)
     Sparkle_AddMenuItem(apple->GetHMenu(), _(L"Check for Updates…").utf8_str());
 #endif
 
+    wxMenu *fileMenu = nullptr;
+    wxMenuItem *fileCloseItem = bar->FindItem(wxID_CLOSE, &fileMenu);
+    if (fileMenu && fileCloseItem)
+    {
+        NSMenuItem *nativeCloseItem = [fileMenu->GetHMenu() itemWithTitle:str::to_NS(fileCloseItem->GetItemLabelText())];
+        if (nativeCloseItem)
+        {
+            nativeCloseItem.target = nil;
+            nativeCloseItem.action = @selector(performClose:);
+        }
+    }
+
     int editMenuPos = bar->FindMenu(_("&Edit"));
     if (editMenuPos == wxNOT_FOUND)
         editMenuPos = 1;
@@ -1140,15 +1155,15 @@ void PoeditApp::TweakOSXMenuBar(wxMenuBar *bar)
 
     }
 
-    int windowMenuPos = bar->FindMenu(_("Window"));
-    if (windowMenuPos != wxNOT_FOUND)
+    if (!m_nativeMacAppData->windowMenu)
     {
-        NSMenu *windowNS = bar->GetMenu(windowMenuPos)->GetHMenu();
-        AddNativeItem(windowNS, -1, _("Minimize"), @selector(performMiniaturize:), @"m");
-        AddNativeItem(windowNS, -1, _("Zoom"), @selector(performZoom:), @"");
-        [windowNS addItem:[NSMenuItem separatorItem]];
-        AddNativeItem(windowNS, -1, _("Bring All to Front"), @selector(arrangeInFront:), @"");
-        [NSApp setWindowsMenu:windowNS];
+        NSMenu *windowMenu = [[NSMenu alloc] initWithTitle:str::to_NS(_("Window"))];
+        AddNativeItem(windowMenu, -1, _("Minimize"), @selector(performMiniaturize:), @"m");
+        AddNativeItem(windowMenu, -1, _("Zoom"), @selector(performZoom:), @"");
+        [windowMenu addItem:[NSMenuItem separatorItem]];
+        AddNativeItem(windowMenu, -1, _("Bring All to Front"), @selector(arrangeInFront:), @"");
+        [NSApp setWindowsMenu:windowMenu];
+        m_nativeMacAppData->windowMenu = windowMenu;
     }
 }
 
@@ -1169,44 +1184,55 @@ void PoeditApp::CreateFakeOpenRecentMenu()
     [openRecentMenu performSelector:@selector(_setMenuName:) withObject:@"NSRecentDocumentsMenu"];
     #pragma clang diagnostic pop
     [menu setSubmenu:openRecentMenu forItem:item];
-    m_nativeMacAppData->menuItem = item;
-    m_nativeMacAppData->menu = openRecentMenu;
+    m_nativeMacAppData->recentMenuItem = item;
+    m_nativeMacAppData->recentMenu = openRecentMenu;
  
     item = [openRecentMenu addItemWithTitle:NSLocalizedString(@"Clear Menu", nil)
             action:@selector(clearRecentDocuments:)
             keyEquivalent:@""];
 }
 
-void PoeditApp::InstallOpenRecentMenu(wxMenuBar *bar)
+void PoeditApp::FixupMenusForMac(wxMenuBar *bar)
 {
-    if (m_nativeMacAppData->menuItem)
-        [m_nativeMacAppData->menuItem setSubmenu:nil];
     m_nativeMacAppData->menuBar = nullptr;
 
+    if (m_nativeMacAppData->recentMenuItem)
+        [m_nativeMacAppData->recentMenuItem setSubmenu:nil];
+    if (m_nativeMacAppData->windowMenuItem)
+        [m_nativeMacAppData->windowMenuItem setSubmenu:nil];
+
     if (!bar)
         return;
 
     wxMenu *fileMenu;
     wxMenuItem *item = bar->FindItem(XRCID("open_recent"), &fileMenu);
-    if (!item)
-        return;
+    if (item)
+    {
+        NSMenu *native = fileMenu->GetHMenu();
+        NSMenuItem *nativeItem = [native itemWithTitle:str::to_NS(item->GetItemLabelText())];
+        if (nativeItem)
+        {
+            [nativeItem setSubmenu:m_nativeMacAppData->recentMenu];
+            m_nativeMacAppData->recentMenuItem = nativeItem;
+        }
+    }
 
-    NSMenu *native = fileMenu->GetHMenu();
-    NSMenuItem *nativeItem = [native itemWithTitle:str::to_NS(item->GetItemLabelText())];
-    if (!nativeItem)
-        return;
+    NSMenuItem *windowItem = [[NSApp mainMenu] itemWithTitle:str::to_NS(_("Window"))];
+    if (windowItem)
+    {
+        [windowItem setSubmenu:m_nativeMacAppData->windowMenu];
+        m_nativeMacAppData->windowMenuItem = windowItem;
+    }
 
-    [nativeItem setSubmenu:m_nativeMacAppData->menu];
-    m_nativeMacAppData->menuItem = nativeItem;
     m_nativeMacAppData->menuBar = bar;
 }
 
-void PoeditApp::OnIdleInstallOpenRecentMenu(wxIdleEvent& event)
+void PoeditApp::OnIdleFixupMenusForMac(wxIdleEvent& event)
 {
     event.Skip();
     auto installed = wxMenuBar::MacGetInstalledMenuBar();
     if (m_nativeMacAppData->menuBar != installed)
-        InstallOpenRecentMenu(installed);
+        FixupMenusForMac(installed);
 }
 
 void PoeditApp::OSXOnWillFinishLaunching()
