@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 1999-2017 Vaclav Slavik
+ *  Copyright (C) 1999-2018 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -335,7 +335,8 @@ private:
         void RecreatePluralTextCtrls();
 
         template<typename TFunctor>
-        void ReportValidationErrors(int errors, Catalog::CompilationStatus mo_compilation_status,
+        void ReportValidationErrors(Catalog::ValidationResults validation,
+                                    Catalog::CompilationStatus mo_compilation_status,
                                     bool from_save, bool other_file_saved,
                                     TFunctor completionHandler);
 
