@@ -1,7 +1,7 @@
-﻿/*
+/*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2000-2017 Vaclav Slavik
+ *  Copyright (C) 2000-2018 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -96,7 +96,7 @@ bool ReadOutput(wxInputStream& s, wxArrayString& out)
 {
     // the stream could be already at EOF or in wxSTREAM_BROKEN_PIPE state
     s.Reset();
-    wxTextInputStream tis(s, " ", wxConvUTF8);
+    wxTextInputStream tis(s, " ", wxConvAuto() /* UTF-8, fallback if impossible */);
 
     while (true)
     {
