@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2004-2017 Vaclav Slavik
+ *  Copyright (C) 2004-2018 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -69,7 +69,11 @@ bool ShouldBeMirorredInRTL(const wxArtID& id, const wxArtClient& client)
         "ContributeOn",
         "poedit-status-comment",
         "follow-link",
-        "sidebar"
+        "sidebar",
+        "Welcome_EditTranslation",
+        "Welcome_CreateTranslation",
+        "Welcome_WordPress",
+        "Welcome_Collaborate"
     };
 
     bool mirror = s_directional.find(id) != s_directional.end();
@@ -148,7 +152,7 @@ wxBitmap PoeditArtProvider::CreateBitmap(const wxArtID& id_,
     }
 
 #ifdef __WXMSW__
-    if (IsWindows10OrGreater())
+    if (client == wxART_TOOLBAR && IsWindows10OrGreater())
     {
         const int padding = PX(1);
         auto sz = img.GetSize();
