@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2001-2017 Vaclav Slavik
+ *  Copyright (C) 2001-2018 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -478,9 +478,9 @@ void ManagerFrame::OnUpdateProject(wxCommandEvent&)
                 UpdateResultReason reason;
                 if (PerformUpdateFromSources(this, cat, reason, Update_DontShowSummary))
                 {
-                    int validation_errors = 0;
+                    Catalog::ValidationResults validation_results;
                     Catalog::CompilationStatus mo_status;
-                    cat->Save(f, false, validation_errors, mo_status);
+                    cat->Save(f, false, validation_results, mo_status);
                 }
             }
          }
