@@ -1,7 +1,7 @@
-﻿/*
+/*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2017 Vaclav Slavik
+ *  Copyright (C) 2017-2018 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -231,6 +231,8 @@ private:
             {
                 case '.':
                     return trans == L'。';
+                case ',':
+                    return trans == L'、';
                 case '!':
                     return trans == L'！';
                 case '?':
@@ -245,7 +247,7 @@ private:
                     break;
             }
         }
-        else if (m_lang == "ar")
+        else if (m_lang == "ar" || m_lang == "fa")
         {
             // In Arabic (but not other RTL languages), some punctuation is mirrored.
             switch (src)
