@@ -1,7 +1,7 @@
-﻿/*
+/*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 1999-2017 Vaclav Slavik
+ *  Copyright (C) 1999-2018 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -842,6 +842,14 @@ void TranslationTextCtrl::DoSetValue(const wxString& value, int flags)
 }
 #endif
 
+#ifdef __WXMSW__
+void TranslationTextCtrl::DoEnable(bool enable)
+{
+    wxEventBlocker block(this, wxEVT_TEXT);
+    AnyTranslatableTextCtrl::DoEnable(enable);
+}
+#endif
+
 void TranslationTextCtrl::SetPlainTextUserWritten(const wxString& value)
 {
     UndoGroup undo(this);
